==> dde-network-core_1.0.57.orig.tar.xz: dde-network-core-1.0.57/dss-network-plugin/translations/dss-network-plugin_vi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="vi" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 tin nhắn mới</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 đã kết nối</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Kết nối Có dây</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Điểm truy cập</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Giao thức</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Loại bảo mật</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Băng tần</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kênh</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Giao diện</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Mặt nạ mạng</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Cổng vào</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Đầu</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Tiền tố</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Tốt độ</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Thiết bị bị vô hiệu hóa</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Đã kết nối nhưng không có truy cập Internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Không được kết nối</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Mạng dây đã ngắt</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Đang kết nối</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Đang xác nhận</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Đang lấy địa chỉ IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Đã kết nối</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Đã ngắt kết nối</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>Thất bại</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Mạng kết nối dây</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Mạng kết nối dây %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Mạng không dây</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Mạng Không dây %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Thiết bị bị vô hiệu hóa</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Mạng dây đã ngắt</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Không được kết nối</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Đang kết nối</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Đã kết nối nhưng không có truy cập Internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Tắt kết nối mạng dây</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Mở kết nối mạng dây</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Tắt kết nối wifi</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Bật kết nối wifi</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Vô hiệu hóa mạng</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Cho phép mạng</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Thiết lập mạng</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.4.orig.tar.xz: dde-network-core-1.1.4/dss-network-plugin/translations/dss-network-plugin_vi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="vi">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 tin nhắn mới</translation>
    </message>
</context>
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Mạng không dây</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Mạng kết nối dây</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 đã kết nối</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Kết nối với mạng ẩn</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mật mã</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Hủy</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Kết nối</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Điểm truy cập</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Giao thức</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Loại bảo mật</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kênh</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Băng tần</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Giao diện</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Mặt nạ mạng</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Cổng vào</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Đầu</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Tiền tố</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Tốt độ</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Thiết bị bị vô hiệu hóa</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Đã kết nối nhưng không có truy cập Internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Không được kết nối</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Mạng dây đã ngắt</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Đang kết nối</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Đang xác nhận</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Đang lấy địa chỉ IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Đã kết nối</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Đã ngắt kết nối</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>Thất bại</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Mạng kết nối dây</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Mạng kết nối dây %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Mạng không dây</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Mạng Không dây %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Thiết bị bị vô hiệu hóa</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Mạng dây đã ngắt</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Không được kết nối</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Đang kết nối</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Đã kết nối nhưng không có truy cập Internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Tắt kết nối mạng dây</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Mở kết nối mạng dây</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Tắt kết nối wifi</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Bật kết nối wifi</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Vô hiệu hóa mạng</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Cho phép mạng</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Thiết lập mạng</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Kết nối Có dây</translation>
    </message>
</context>
</TS>
